import { createRouter, createWebHashHistory } from "vue-router";

const routes = [
  {
    path: "/",
    name: "Program",
    component: () => import("../views/Program.vue"),
  },
  {
    path: "/Channel",
    name: "Channel",
    component: () => import("../views/Channel.vue"),
  },
  {
    path: "/heightlight",
    name: "Heightlight",
    component: () => import("../views/Heightlight.vue"),
  },
  {
    path: "/realData",
    name: "RealData",
    component: () => import("../views/RealData.vue"),
  },
  {
    path: "/liveChannel",
    name: "LiveChannel",
    component: () => import("../views/LiveChannel.vue"),
  },
  {
    path: "/boutiqueColumn",
    name: "boutiqueColumn",
    component: () => import("../views/BoutiqueColumn/BoutiqueColumn.vue"),
  },
  {
    path: "/activity",
    name: "Activity",
    component: () => import("../views/Activity/Activity.vue"),
  },
  {
    path: "/jugou",
    name: "Jugou",
    component: () => import("../views/Jugou/Jugou.vue"),
  },
  {
    path: "/radio",
    name: "Radio",
    component: () => import("../views/Radio/Radio.vue"),
  },
  {
      path: "/hardAdvertisement",
      name: "HardAdvertisement",
      component: () => import("../views/HardAdvertisement/HardAdvertisement.vue"),
  },
  {
      path: "/advertisingEye",
      name: "AdvertisingEye",
      component: () => import("../views/AdvertisingEye/AdvertisingEye.vue"),
  },
  {
      path: "/channelRanking",
      name: "ChannelRanking",
      component: () => import("../views/ChannelRanking/ChannelRanking.vue"),
  },
  {
      path: "/reportForm",
      name: "ReportForm",
      component: () => import("../views/ReportForm/ReportForm.vue"),
  },
  {
      path: "/radioBroadcast",
      name: "RadioBroadcast",
      component: () => import("../views/RadioBroadcast.vue")
  },
  {
    path: "/realOnline",
    name: "RealOnline",
    component: () => import("../views/RealOnline/index.vue")
  },
  {
    path: "/history",
    name: "History",
    component: () => import("../views/History/index.vue")
  },

  {
    path: "/country",
    component: () => import("../views/Country/Index.vue"),
    children: [
        {
            path: "", // 频道全天节目
            component: ()=> import("../views/ChannelEPG/Channel.vue")
        },
        {
            path: "/country/customRanking", // 自定义时间段排行
            component: ()=> import("../views/CustomRanking/CustomRanking.vue")
        },
        {
            path: "/country/channelList", // 多维度筛选 频道时段排名
            component: ()=> import("../views/ChannelList/ChannelList.vue")
        },
        {
            path: "/country/singleDay", // 单天频道点分钟
            component: ()=> import("../views/SingleDay/SingleDay.vue")
        },
        {
            path: "/country/average", // 平均频道点分钟
            component: ()=> import("../views/Average/Average.vue")
        },
        {
            path: "/country/subRegion", // 频道分地收视（全国）
            component: ()=> import("../views/SubRegion/SubRegion.vue")
        },
        {
            path: "/country/channelRegion", // 频道分地区收视
            component: ()=> import("../views/ChannelRegion/ChannelRegion.vue")
        },
        {
            path: "/country/flowChannel", // 频道实时流入流出
            component: ()=> import("../views/FlowChannel/FlowChannel.vue")
        },

        {
            path: "/country/program", // 节目点分钟
            component: ()=> import("../views/Program/Program.vue")
        },
        {
            path: "/country/compete", // 节目竞争一览
            component: ()=> import("../views/Compete/Compete.vue")
        },
        {
            path: "/country/specificProgramQuery", // 具体节目剧目查询
            component: ()=> import("../views/SpecificProgramQuery/SpecificProgramQuery.vue")
        },
        {
            path: "/country/specificProgram", // 具体节目剧目排行
            component: ()=> import("../views/SpecificProgram/SpecificProgram.vue")
        },
        {
            path: "/country/abstractProgramQuery", // 抽象节目剧目查询
            component: ()=> import("../views/AbstractProgramQuery/AbstractProgramQuery.vue")
        },
        {
            path: "/country/abstractProgram", // 抽象节目剧目排行
            component: ()=> import("../views/AbstractProgram/AbstractProgram.vue")
        },
        {
            path: "/country/flow", // 单期节目流入流出
            component: ()=> import("../views/Flow/Flow.vue")
        },
        {
            path: "/country/abstract", // 抽象节目剧目分地区收视（全国）
            component: ()=> import("../views/Abstract/Abstract.vue")
        },
        {
            path: "/country/overlap", // 节目剧目重叠度
            component: ()=> import("../views/Overlap/Overlap.vue")
        },
        {
            path: "/country/scheduling", // 电视剧排播信息及表现（全国）
            component: ()=> import("../views/Scheduling/Scheduling.vue")
        },
    ],
  },
];
// 实时/单期 节目流入流出 共计2个  可以使用同一模块
// 具体/抽象 节目剧目 查询/排行  共计4个，可以使用一个模块
const router = createRouter({
  history: createWebHashHistory(process.env.BASE_URL),
  routes,
});

export default router;
